Licenses
========

This directory holds license and credit information for the package,
works the package is derived from, and/or datasets.

This package links against `IRBEM <https://prbem.github.io/IRBEM/>_` which is
released under the terms of the GNU Lesser General Public License as published
by the Free Software Foundation, either version 3 of the License, or (at your
option) any later version.
